@@ -7,6 +7,9 @@ test_that("addMarker() works on ped list", {
 
   z = addMarker(x, "1" = "1/2", alleles = 1:3)
   expect_equal(alleles(z, 1), as.character(1:3))
+
+  expect_equal(addMarker(x, alleles = 1:2), list(addMarker(x[[1]], alleles = 1:2),
+                                                 addMarker(x[[2]], alleles = 1:2)))
 })
 
 
@@ -21,8 +24,7 @@ test_that("setMarkers() creates empty markers with locusAttributes", {
 })
 
 test_that("addMarkers() adds empty markers with locusAttributes", {
-  x = nuclearPed(1)
-  x = setMarkers(x, marker(x, name="M0"))
+  x = nuclearPed(1) |> addMarker(name = "M0")
 
   ann = list(list(alleles=1:2, name="snp1"), list(alleles=c("a", "b")))
   x = addMarkers(x, locusAttributes=ann)
